@@ -2,8 +2,8 @@ package HTTP::Engine::Interface::FCGI;
 use Moose;
 with 'HTTP::Engine::Role::Interface';
 use constant should_write_response_line => 0;
+use constant RUNNING_IN_HELL => $^O eq 'MSWin32';
 use FCGI;
-use UNIVERSAL::require;
 
 has leave_umask => (
     is      => 'ro',
@@ -66,7 +66,7 @@ sub run {
             umask($old_umask);
         }
     }
-    elsif ( $^O ne 'MSWin32' ) {
+    elsif ( !RUNNING_IN_HELL ) {
         -S STDIN
           or die "STDIN is not a socket; specify a listen location";
     }
